#!/bin/sh
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
# (C) 2010 RodolfoRG <rodolforg@gmail.com>

INSTALLPATH="/mnt/sd/game/"

FILENAME="$1"
DIRECTORY="$2"
ARCHIVE_TYPE=$3

echo "START"

# Check if archive file exists
if [ \! -e "$FILENAME" ]
then
	echo `basename "$FILENAME"` "doesn't exist!"
	echo "DONE"
	exit
fi

echo "Unpacking..."

# Create tmp directory
if [ \! -d "$DIRECTORY" ]
then
	mkdir "$DIRECTORY"
fi

# Check if directory for extracted items isn't root
if [ x"$DIRECTORY" = x"/" ]
then
	echo "Directory for temporary extraction shall not be root."
	exit 1
fi

# Decompress to temporary directory
case $ARCHIVE_TYPE in
	zip)
		(unzip -o "$FILENAME" -d "$DIRECTORY" >/dev/null 2>descomp.err) || (rm descomp.err && ./utils/miniunz "$FILENAME" -o -d "$DIRECTORY" >/dev/null 2>descomp.err)
		;;
	gzip)
		tar xzf "$FILENAME" -C "$DIRECTORY" >/dev/null 2>descomp.err
		;;
	bz2)
		tar xjf "$FILENAME" -C "$DIRECTORY" >/dev/null 2>descomp.err
		;;
	7zip)
		echo "7zip is unsupported"
		echo "DONE"
		exit
		;;
	rar)
		(unrar x -y "$FILENAME" "$DIRECTORY" >/dev/null 2>descomp.err) || (./utils/unrar x -y "$FILENAME" "$DIRECTORY" >/dev/null 2>>descomp.err)
		;;
	*)
		echo "Unknown archive format"
		echo "DONE"
		exit
esac

# Check for decompression error
if [ $? -ne 0 ] #-o -e descomp.err ]
then
	echo "Decompression error"
	cat descomp.err
	echo "DONE"
	rm descomp.err
	exit
fi

echo `basename "$FILENAME"` "extracted"
echo "DONE"
